tiled.adapters.dataframe.DataFrameAdapter
=========================================

.. currentmodule:: tiled.adapters.dataframe

.. autoclass:: DataFrameAdapter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DataFrameAdapter.__init__
      ~DataFrameAdapter.from_pandas
      ~DataFrameAdapter.items
      ~DataFrameAdapter.macrostructure
      ~DataFrameAdapter.microstructure
      ~DataFrameAdapter.read
      ~DataFrameAdapter.read_csv
      ~DataFrameAdapter.read_partition
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DataFrameAdapter.metadata
      ~DataFrameAdapter.structure_family
   
   